@@ -13,7 +13,9 @@
 
 (texmacs-module (dynamic fold-menu)
   (:use (dynamic fold-edit)
-        (generic generic-menu)))
+        (generic generic-menu)
+	(generic document-menu)
+        (generic format-widgets)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Menus for direct folding and switching
@@ -21,17 +23,17 @@
 
 (menu-bind fold-menu
   (when (with t (tree-innermost dynamic-context?)
-	  (and t (toggle-second-context? t)))
+          (and t (toggle-second-context? t)))
     ("Fold" (dynamic-previous)))
   (when (with t (tree-innermost dynamic-context?)
-	  (and t (toggle-first-context? t)))
+          (and t (toggle-first-context? t)))
     ("Unfold" (dynamic-next))))
 
 (menu-bind switch-menu
   (when (with t (tree-innermost dynamic-context?)
-	  (and t (switch-context? t)))
-    ("Add branch before" (switch-insert-at (focus-tree) :current))
-    ("Add branch after" (switch-insert-at (focus-tree) :var-next))
+          (and t (switch-context? t)))
+    ("Add branch before" (switch-insert-at (focus-tree) :current #f))
+    ("Add branch after" (switch-insert-at (focus-tree) :var-next #f))
     ("Remove this branch" (switch-remove-at (focus-tree) :current))
     ---
     (when (switch-index (focus-tree))
@@ -93,10 +95,10 @@
         ("Screens" (make-screens)))
       ("Tiny" (make-switch 'tiny-switch)))
   (-> "Unroll"
-      ("Default" (make-switch 'unroll))
-      ("Compressed" (make-switch 'unroll-compressed)) 
-      ("Phantoms" (make-switch 'unroll-phantoms))
-      ("Greyed" (make-switch 'unroll-greyed))
+      ("Default" (make-unroll 'unroll))
+      ("Compressed" (make-unroll 'unroll-compressed))
+      ("Phantoms" (make-unroll 'unroll-phantoms))
+      ("Greyed" (make-unroll 'unroll-greyed))
       ---
       ("Itemize" (make-switch-list 'unroll 'itemize))
       ("Enumerate" (make-switch-list 'unroll 'enumerate))
@@ -135,8 +137,10 @@
       ("Fold back" (make 'fold-back))
       ("Keep unfolded" (make 'keep-unfolded))
       (if #f
-	  ("Animate folding" (noop))
-	  ("Animate unfolding" (noop)))))
+          ("Animate folding" (noop))
+          ("Animate unfolding" (noop))))
+  (if (== (get-preference "experimental encryption") "on")
+      (-> "Encrypt" (link gpg-menu))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Operate on buffers with dynamic markup
@@ -179,8 +183,7 @@
       ("Change tags" (dynamic-operate-on-buffer :var-compress)))
   (-> "Expand"
       ("Preserve tags" (dynamic-operate-on-buffer :expand))
-      ("Change tags" (dynamic-operate-on-buffer :var-expand))
-      ("Make slides" (dynamic-make-slides)))
+      ("Change tags" (dynamic-operate-on-buffer :var-expand)))
   (-> "Filter"
       ("Remove folded" (dynamic-filter-buffer :remove-folded))
       ("Remove unfolded" (dynamic-filter-buffer :remove-unfolded))
@@ -240,11 +243,6 @@
 ;; Propose insertion of 'screens' tag in beamer style
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(tm-define (screens-buffer?)
-  (with t (buffer-tree)
-    (and (tree-is? t 'document)
-         (tree-is? t :last 'screens))))
-
 (tm-define (make-screens)
   (let* ((t (buffer-tree))
          (l (tree-children t))
@@ -287,42 +285,119 @@
   #f)
 
 (tm-define (slide-propose-title? t)
-  (and-with u (tree-ref t :down :down)
-    (and (tree-is? u 'document)
-         (not (tree-is? u 0 'tit)))))
+  (and-with u (slide-get-document t)
+    (not (tree-is? u 0 'tit))))
 
 (tm-define (slide-insert-title t)
-  (with u (tree-ref t :down :down)
+  (and-with u (slide-get-document t)
     (tree-insert u 0 '((tit "")))
     (tree-go-to u 0 0 0)))
 
-(tm-define (search-slide-name t)
-  (cond ((tree-in? t '(shown hidden document))
-         (search-slide-name (tree-ref t 0)))
-        ((tree-is? t 'tit)
-         (texmacs->code (verbatim-expand (tm-ref t 0)) "cork"))
-        (else "")))
+(tm-define (search-slide-name t*)
+  (with t (slide-get-document t*)
+    (if (and (tree-is? t 'document)
+             (tree-is? t 0 'tit))
+        (texmacs->code (verbatim-expand (tm-ref t 0 0)) "cork")
+        "")))
 
 (tm-define (get-slide-name t i)
   (with s (search-slide-name t)
     (string-append "Slide " (number->string (+ i 1))
                    (if (== s "") "" (string-append ": " s)))))
 
-(tm-menu (focus-slides-menu t)
-  (for (i (.. 0 (tree-arity t)))
-    ((eval (get-slide-name (tree-ref t i) i))
-     (switch-to t i))))
+(tm-menu (focus-slides-menu t*)
+  (with t (slide-get-switch t*)
+    (for (i (.. 0 (tree-arity t)))
+      ((eval (get-slide-name (tree-ref t i) i))
+       (screens-switch-to i)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Menus shen focus is on 'screens' tag
+;; Graphical slides
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-define (slide-propose-graphics? t)
+  (and-with u (slide-get-document t)
+    (or (tm-equal? u '(document ""))
+        (and (tree-func? u 'document 1)
+             (tree-is? u 0 'tit))
+        (and (tree-func? u 'document 2)
+             (tree-is? u 0 'tit)
+             (tm-equal? (tree-ref u 1) "")))))
+
+(tm-define (slide-insert-graphics t)
+  (and-with u (slide-get-document t)
+    (when (and (tree-func? u 'document 1)
+               (tree-is? u 0 'tit))
+      (tree-insert! u 1 (list "")))
+    (tree-set u :last `(gr-screen (document "")))
+    (tree-go-to u :last 0 0 0)
+    (make-graphics
+     "gr-mode" "point"
+     "gr-frame" `(tuple "scale" "1cm" (tuple "0gw" "1gh"))
+     "gr-geometry" `(tuple "geometry" "1gpar" "1gpag" "axis"))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Slide background color
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-widget (slide-page-formatter quit)
+  (let* ((col (tm->stree (slide-get-bg-color)))
+         (setter (lambda (c)
+                   (set! col c)
+                   (slide-set-bg-color col)
+                   (refresh-now "slide-color-sample"))))
+    (padded
+      (bold (text "Background color"))
+      ===
+      (hlist
+        (refreshable "slide-color-sample"
+          (resize "150px" "100px"
+            (texmacs-output `(document
+                               (block
+                                (tformat
+                                 (cwith "1" "1" "1" "1" "cell-width" "140px")
+                                 (cwith "1" "1" "1" "1" "cell-height" "90px")
+                                 (cwith "1" "1" "1" "1" "cell-vmode" "exact")
+                                 (cwith "1" "1" "1" "1" "cell-background" ,col)
+                                 (table (row (cell ""))))))
+                            `(style (tuple "generic")))))
+        // // //
+        (explicit-buttons
+          (vlist
+            ("Color" (interactive-color setter (list)))
+            ("Pattern" (open-pattern-selector setter "1cm"))
+            (glue #f #t 0 0))))
+      ======
+      (explicit-buttons
+        (hlist
+          >>>
+          ("Ok" (quit)))))))
+
+(tm-define (open-page-format)
+  (:require (or (inside? 'screens) (inside? 'slideshow)))
+  (dialogue-window slide-page-formatter noop "Page format"))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Menus when focus is on 'screens' tag
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (focus-can-move? t)
-  (:require (tree-is? t 'screens))
+  (:require (screens-context? t))
   #f)
 
+(tm-menu (focus-tag-menu t)
+  (:require (screens-context? t))
+  (inert ((eval (focus-tag-name (tree-label t))) (noop) (noop)))
+  (-> (eval (upcase-first (get-init "page-type")))
+      (link document-page-size-menu))
+  (-> (eval (upcase-first (get-init-page-rendering)))
+      (link page-rendering-menu))
+  (-> "Preferences"
+      (dynamic (focus-preferences-menu t)))
+  ("Describe" (focus-help)))
+
 (tm-menu (standard-focus-menu t)
-  (:require (tree-is? t 'screens))
+  (:require (screens-context? t))
   (dynamic (focus-style-menu t))
   ---
   (dynamic (focus-tag-menu t))
@@ -332,24 +407,46 @@
   (dynamic (focus-slides-menu t))
   (assuming (slide-propose-title? t)
     ---
-    ("Title" (slide-insert-title t))))
+    ("Title" (slide-insert-title t)))
+  (assuming (slide-propose-graphics? t)
+    ---
+    ("Draw" (slide-insert-graphics t))))
+
+(tm-menu (focus-tag-icons t)
+  (:require (screens-context? t))
+  (mini #t (inert ((eval (focus-tag-name (tree-label t))) (noop))))
+  (=> (balloon (eval (upcase-first (get-init "page-type")))
+               "Paper size")
+      (link document-page-size-menu))
+  (=> (balloon (icon (eval (current-page-icon))) "Page layout")
+      (link page-rendering-menu))
+  (assuming (focus-has-preferences? t)
+    (=> (balloon (icon "tm_focus_prefs.xpm") "Preferences for tag")
+	(dynamic (focus-preferences-menu t))))
+  ((balloon (icon "tm_focus_help.xpm") "Describe tag")
+   (focus-help)))
 
 (tm-menu (standard-focus-icons t)
-  (:require (tree-is? t 'screens))
+  (:require (screens-context? t))
   (dynamic (focus-style-icons t))  
   //
   (minibar (dynamic (focus-insert-icons t)))
   //
   (minibar (dynamic (focus-tag-icons t)))
   //
-  (with i (tree-index (tree-down t))
-    (mini #t
-      (=> (eval (get-slide-name (tree-ref t i) i))
-          (dynamic (focus-slides-menu t)))))
+  (with u (slide-get-switch t)
+    (with i (tree-index (tree-down u))
+      (mini #t
+        (=> (eval (get-slide-name (tree-ref u i) i))
+            (dynamic (focus-slides-menu t))))))
   (assuming (slide-propose-title? t)
     //
     (minibar
-     ((balloon "Title" "Insert title") (slide-insert-title t)))))
+     ((balloon "Title" "Insert title") (slide-insert-title t))))
+  (assuming (slide-propose-graphics? t)
+    //
+    (minibar
+     ((balloon "Draw" "Draw graphics") (slide-insert-graphics t)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Menu customizations for overlays
@@ -371,12 +468,12 @@
   (:require (== l "overlay-nr"))
   #f)
 
-(define (get-overlays-menu-name t)
+(define (get-overlays-menu-name prefix t)
   (let* ((cur (overlays-current t))
          (tot (overlays-arity t)))
     (set! cur (if cur (number->string cur) "?"))
     (set! tot (if tot (number->string tot) "?"))
-    (string-append "Overlay " cur "/" tot)))
+    (string-append prefix cur "/" tot)))
 
 (tm-menu (focus-overlays-menu t)
   (for (i (.. 1 (or (+ (overlays-arity t) 1) 2)))
@@ -391,7 +488,7 @@
 (tm-menu (focus-hidden-icons t)
   (:require (overlays-context? t))
   //
-  (=> (eval (get-overlays-menu-name t))
+  (=> (eval (get-overlays-menu-name "Overlay " t))
       (dynamic (focus-overlays-menu t))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -415,3 +512,66 @@
   (:require (overlay-context? t))
   //
   (dynamic (focus-overlay-icons t)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Overlays in graphics mode
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (proviso-name p)
+  (cond ((== p "mixed") "mixed")
+        ((tm-func? p 'show-this 1) "=")
+        ((tm-func? p 'show-from 1) ">=")
+        ((tm-func? p 'show-until 1) "<=")
+        (else "*")))
+
+(tm-menu (graphics-overlays-mode-menu)
+  (let* ((t (tree-innermost overlays-context?))
+         (cur (and t (number->string (overlays-current t)))))
+    ("This" (graphics-set-proviso `(show-this ,cur)))
+    ("From" (graphics-set-proviso `(show-from ,cur)))
+    ("Until" (graphics-set-proviso `(show-until ,cur)))
+    ("Always" (graphics-set-proviso "default"))))
+
+(tm-menu (graphics-focus-overlays-menu)
+  (with t (tree-innermost overlays-context?)
+    (assuming (nnot t)
+      ---
+      (-> "Overlay mode"
+          (link graphics-overlays-mode-menu))
+      (-> (eval (get-overlays-menu-name "Overlay " t))
+          (dynamic (focus-overlays-menu t))))))
+
+(tm-menu (graphics-focus-overlays-icons)
+  (with t (tree-innermost overlays-context?)
+    (assuming (nnot t)
+      /
+      (mini #t
+        (group "Overlay:")
+        (=> (eval (proviso-name (graphics-get-proviso)))
+            (link graphics-overlays-mode-menu))
+        (=> (eval (get-overlays-menu-name "" t))
+            (dynamic (focus-overlays-menu t)))))))
+
+(tm-menu (graphics-screens-menu)
+  (with t (tree-innermost screens-context?)
+    (assuming (nnot t)
+      ("Insert slide before" (structured-insert-horizontal t #f))
+      ("Insert slide after"  (structured-insert-horizontal t #t))
+      ("Remove slide before" (structured-remove-horizontal t #f))
+      ("Remove slide after"  (structured-remove-horizontal t #t)))))
+
+(tm-menu (graphics-overlays-manage-menu)
+  (with t (tree-innermost overlays-context?)
+    (assuming (nnot t)
+      ("Insert overlay before" (structured-insert-horizontal t #f))
+      ("Insert overlay after"  (structured-insert-horizontal t #t))
+      ("Remove overlay before" (structured-remove-horizontal t #f))
+      ("Remove overlay after"  (structured-remove-horizontal t #t)))))
+
+(tm-menu (graphics-overlays-menu)
+  (with t (tree-innermost overlays-context?)
+    (assuming (not t)
+      ("Insert overlay before" (make-gr-overlays #f))
+      ("Insert overlay after" (make-gr-overlays #t)))
+    (assuming t
+      (link graphics-overlays-manage-menu))))
