@@ -193,7 +193,8 @@
 (tm-property (open-search) (:interactive #t))
 (tm-property (open-replace) (:interactive #t))
 (tm-property (open-paragraph-format) (:interactive #t))
-(tm-property (open-page-format) (:interactive #t))
+(tm-property (open-page-format) (:interactive #t)
+                                (:applicable (not (selection-active?))))
 (tm-property (open-source-tree-preferences) (:interactive #t))
 (tm-property (open-document-paragraph-format) (:interactive #t))
 (tm-property (open-document-page-format) (:interactive #t))
