@@ -40,7 +40,7 @@
     (shortcut :menu-wide-label :string?)))
   (:menu-item (:or
     ---
-    |
+    | ;; |
     (group :%1)
     (text :%1)
     (glue :boolean? :boolean? :integer? :integer?)
@@ -362,6 +362,14 @@
         (menu-label-add-dots label)
         label)))
 
+(define (make-menu-entry-style style action)
+  (with source (promise-source action)
+    (if (not (pair? source)) style
+	(with prop (property (car source) :applicable)
+	  (if (or (not prop) (apply (car prop) (list)))
+	      style
+	      (logior style (+ widget-style-inert widget-style-grey)))))))
+
 (define (make-menu-entry-attrs label action opt-key opt-check)
   (cond ((match? label '(shortcut :%1 :string?))
          (make-menu-entry-attrs (cadr label) action (caddr label) opt-check))
@@ -374,7 +382,9 @@
       (label action opt-key opt-check)
       (make-menu-entry-attrs (car p) (cAr p) #f #f)
     (make-menu-entry-button
-     style bar? (tuple? (car p) 'balloon 2)
+     (make-menu-entry-style style action)
+     bar?
+     (tuple? (car p) 'balloon 2)
      (make-menu-entry-check opt-check action)
      (make-menu-entry-dots label action)
      (make-menu-entry-shortcut label action opt-key)
@@ -936,28 +946,54 @@
   (:argument style "menu style")
   ((wrap-catch make-menu-main) p style))
 
-(tm-define (top-window menu-promise name . opt-quit)
-  (:interactive #t)
-  (let* ((win (alt-window-handle))
-         (qqq (lambda () (if (nnull? opt-quit) ((car opt-quit)))))
-         (qui (object->command (lambda () (qqq) (alt-window-delete win))))
-         (men (menu-promise))
-         (scm (list 'vertical men))
-         (wid (make-menu-widget scm 0)))
-    (alt-window-create-quit win wid name qui)
-    (alt-window-show win)))
+(define (decode-options opts)
+  (let* ((bufs (list))
+         (qcmd noop))
+    (while (and (pair? opts) (url? (car opts)))
+      (set! bufs (cons (car opts) bufs))
+      (set! opts (cdr opts)))
+    (when (pair? opts)
+      (set! qcmd (car opts))
+      (set! opts (cdr opts)))
+    (list bufs qcmd)))
 
-(tm-define (dialogue-window menu-promise cmd name . opt-quit)
+(define window-deleters (make-ahash-table))
+
+(define (make-window-deleter win bufs)
+  (for-each (lambda (buf)
+              (and-with old-del (ahash-ref window-deleters buf) (old-del)))
+            bufs)
+  (with del
+      (lambda ()
+        (for-each (lambda (buf) (ahash-remove! window-deleters buf)) bufs)
+        (alt-window-delete win))
+    (for-each (lambda (buf) (ahash-set! window-deleters buf del)) bufs)
+    del))
+
+(tm-define (top-window menu-promise name . opts)
   (:interactive #t)
-  (let* ((win (alt-window-handle))
-         (qqq (lambda () (if (nnull? opt-quit) ((car opt-quit)))))
-         (qui (object->command (lambda () (qqq) (alt-window-delete win))))
-         (lbd (lambda x (apply cmd x) (alt-window-delete win)))
-         (men (menu-promise lbd))
-         (scm (list 'vertical men))
-         (wid (make-menu-widget scm 0)))
-    (alt-window-create-quit win wid name qui)
-    (alt-window-show win)))
+  (with (bufs qqq) (decode-options opts)
+    (let* ((win (alt-window-handle))
+           (del (make-window-deleter win bufs))
+           (qui (object->command (lambda () (qqq) (del))))
+           (men (menu-promise))
+           (scm (list 'vertical men))
+           (wid (make-menu-widget scm 0)))
+      (alt-window-create-quit win wid name qui)
+      (alt-window-show win))))
+
+(tm-define (dialogue-window menu-promise cmd name . opts)
+  (:interactive #t)
+  (with (bufs qqq) (decode-options opts)
+    (let* ((win (alt-window-handle))
+           (del (make-window-deleter win bufs))
+           (qui (object->command (lambda () (qqq) (del))))
+           (lbd (lambda x (apply cmd x) (del)))
+           (men (menu-promise lbd))
+           (scm (list 'vertical men))
+           (wid (make-menu-widget scm 0)))
+      (alt-window-create-quit win wid name qui)
+      (alt-window-show win))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Other top-level windows
